/*******************************************************************************
* File Name: ENCA_deb.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ENCA_deb.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        ENCA_deb_PC =   (ENCA_deb_PC & \
                                (uint32)(~(uint32)(ENCA_deb_DRIVE_MODE_IND_MASK << (ENCA_deb_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (ENCA_deb_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: ENCA_deb_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void ENCA_deb_Write(uint8 value) 
{
    uint8 drVal = (uint8)(ENCA_deb_DR & (uint8)(~ENCA_deb_MASK));
    drVal = (drVal | ((uint8)(value << ENCA_deb_SHIFT) & ENCA_deb_MASK));
    ENCA_deb_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: ENCA_deb_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  ENCA_deb_DM_STRONG     Strong Drive 
*  ENCA_deb_DM_OD_HI      Open Drain, Drives High 
*  ENCA_deb_DM_OD_LO      Open Drain, Drives Low 
*  ENCA_deb_DM_RES_UP     Resistive Pull Up 
*  ENCA_deb_DM_RES_DWN    Resistive Pull Down 
*  ENCA_deb_DM_RES_UPDWN  Resistive Pull Up/Down 
*  ENCA_deb_DM_DIG_HIZ    High Impedance Digital 
*  ENCA_deb_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void ENCA_deb_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(ENCA_deb__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: ENCA_deb_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ENCA_deb_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ENCA_deb_Read(void) 
{
    return (uint8)((ENCA_deb_PS & ENCA_deb_MASK) >> ENCA_deb_SHIFT);
}


/*******************************************************************************
* Function Name: ENCA_deb_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ENCA_deb_ReadDataReg(void) 
{
    return (uint8)((ENCA_deb_DR & ENCA_deb_MASK) >> ENCA_deb_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ENCA_deb_INTSTAT) 

    /*******************************************************************************
    * Function Name: ENCA_deb_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ENCA_deb_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(ENCA_deb_INTSTAT & ENCA_deb_MASK);
		ENCA_deb_INTSTAT = maskedStatus;
        return maskedStatus >> ENCA_deb_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
