/*******************************************************************************
* File Name: ENCB_deb.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ENCB_deb.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        ENCB_deb_PC =   (ENCB_deb_PC & \
                                (uint32)(~(uint32)(ENCB_deb_DRIVE_MODE_IND_MASK << (ENCB_deb_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (ENCB_deb_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: ENCB_deb_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void ENCB_deb_Write(uint8 value) 
{
    uint8 drVal = (uint8)(ENCB_deb_DR & (uint8)(~ENCB_deb_MASK));
    drVal = (drVal | ((uint8)(value << ENCB_deb_SHIFT) & ENCB_deb_MASK));
    ENCB_deb_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: ENCB_deb_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  ENCB_deb_DM_STRONG     Strong Drive 
*  ENCB_deb_DM_OD_HI      Open Drain, Drives High 
*  ENCB_deb_DM_OD_LO      Open Drain, Drives Low 
*  ENCB_deb_DM_RES_UP     Resistive Pull Up 
*  ENCB_deb_DM_RES_DWN    Resistive Pull Down 
*  ENCB_deb_DM_RES_UPDWN  Resistive Pull Up/Down 
*  ENCB_deb_DM_DIG_HIZ    High Impedance Digital 
*  ENCB_deb_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void ENCB_deb_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(ENCB_deb__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: ENCB_deb_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ENCB_deb_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ENCB_deb_Read(void) 
{
    return (uint8)((ENCB_deb_PS & ENCB_deb_MASK) >> ENCB_deb_SHIFT);
}


/*******************************************************************************
* Function Name: ENCB_deb_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ENCB_deb_ReadDataReg(void) 
{
    return (uint8)((ENCB_deb_DR & ENCB_deb_MASK) >> ENCB_deb_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ENCB_deb_INTSTAT) 

    /*******************************************************************************
    * Function Name: ENCB_deb_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ENCB_deb_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(ENCB_deb_INTSTAT & ENCB_deb_MASK);
		ENCB_deb_INTSTAT = maskedStatus;
        return maskedStatus >> ENCB_deb_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
