/*******************************************************************************
* File Name: .h
* Version 1.20
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PVT_SCBUART_H)
#define CY_SCB_PVT_SCBUART_H

#include "SCBUART.h"


/***************************************
*     Private Function Prototypes
***************************************/

/* APIs to service INTR_I2C_EC register */
#define SCBUART_SetI2CExtClkInterruptMode(interruptMask) SCBUART_WRITE_INTR_I2C_EC_MASK(interruptMask)
#define SCBUART_ClearI2CExtClkInterruptSource(interruptMask) SCBUART_CLEAR_INTR_I2C_EC(interruptMask)
#define SCBUART_GetI2CExtClkInterruptSource()                (SCBUART_INTR_I2C_EC_REG)
#define SCBUART_GetI2CExtClkInterruptMode()                  (SCBUART_INTR_I2C_EC_MASK_REG)
#define SCBUART_GetI2CExtClkInterruptSourceMasked()          (SCBUART_INTR_I2C_EC_MASKED_REG)

#if(!SCBUART_CY_SCBIP_V1_I2C_ONLY)
/* APIs to service INTR_SPI_EC register */
#define SCBUART_SetSpiExtClkInterruptMode(interruptMask) SCBUART_WRITE_INTR_SPI_EC_MASK(interruptMask)
#define SCBUART_ClearSpiExtClkInterruptSource(interruptMask) SCBUART_CLEAR_INTR_SPI_EC(interruptMask)
#define SCBUART_GetExtSpiClkInterruptSource()                 (SCBUART_INTR_SPI_EC_REG)
#define SCBUART_GetExtSpiClkInterruptMode()                   (SCBUART_INTR_SPI_EC_MASK_REG)
#define SCBUART_GetExtSpiClkInterruptSourceMasked()           (SCBUART_INTR_SPI_EC_MASKED_REG)
#endif /* (!SCBUART_CY_SCBIP_V1_I2C_ONLY) */

#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    extern void SCBUART_SetPins(uint32 mode, uint32 subMode, uint32 uartTxRx);
#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Vars with External Linkage
***************************************/

#if !defined (CY_REMOVE_SCBUART_CUSTOM_INTR_HANDLER)
    extern cyisraddress SCBUART_customIntrHandler;
#endif /* !defined (CY_REMOVE_SCBUART_CUSTOM_INTR_HANDLER) */

extern SCBUART_BACKUP_STRUCT SCBUART_backup;

#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common config vars */
    extern uint8 SCBUART_scbMode;
    extern uint8 SCBUART_scbEnableWake;
    extern uint8 SCBUART_scbEnableIntr;

    /* I2C config vars */
    extern uint8 SCBUART_mode;
    extern uint8 SCBUART_acceptAddr;

    /* SPI/UART config vars */
    extern volatile uint8 * SCBUART_rxBuffer;
    extern uint8   SCBUART_rxDataBits;
    extern uint32  SCBUART_rxBufferSize;

    extern volatile uint8 * SCBUART_txBuffer;
    extern uint8   SCBUART_txDataBits;
    extern uint32  SCBUART_txBufferSize;

    /* EZI2C config vars */
    extern uint8 SCBUART_numberOfAddr;
    extern uint8 SCBUART_subAddrSize;
#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*  Conditional Macro
****************************************/

#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Define run time operation mode */
    #define SCBUART_SCB_MODE_I2C_RUNTM_CFG     (SCBUART_SCB_MODE_I2C      == SCBUART_scbMode)
    #define SCBUART_SCB_MODE_SPI_RUNTM_CFG     (SCBUART_SCB_MODE_SPI      == SCBUART_scbMode)
    #define SCBUART_SCB_MODE_UART_RUNTM_CFG    (SCBUART_SCB_MODE_UART     == SCBUART_scbMode)
    #define SCBUART_SCB_MODE_EZI2C_RUNTM_CFG   (SCBUART_SCB_MODE_EZI2C    == SCBUART_scbMode)
    #define SCBUART_SCB_MODE_UNCONFIG_RUNTM_CFG \
                                                        (SCBUART_SCB_MODE_UNCONFIG == SCBUART_scbMode)

    /* Define wakeup enable */
    #define SCBUART_SCB_WAKE_ENABLE_CHECK        (0u != SCBUART_scbEnableWake)
#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */

#endif /* (CY_SCB_PVT_SCBUART_H) */


/* [] END OF FILE */
