/*******************************************************************************
* File Name: TestTimer.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "TestTimer.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        TestTimer_PC =   (TestTimer_PC & \
                                (uint32)(~(uint32)(TestTimer_DRIVE_MODE_IND_MASK << (TestTimer_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (TestTimer_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: TestTimer_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void TestTimer_Write(uint8 value) 
{
    uint8 drVal = (uint8)(TestTimer_DR & (uint8)(~TestTimer_MASK));
    drVal = (drVal | ((uint8)(value << TestTimer_SHIFT) & TestTimer_MASK));
    TestTimer_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: TestTimer_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  TestTimer_DM_STRONG     Strong Drive 
*  TestTimer_DM_OD_HI      Open Drain, Drives High 
*  TestTimer_DM_OD_LO      Open Drain, Drives Low 
*  TestTimer_DM_RES_UP     Resistive Pull Up 
*  TestTimer_DM_RES_DWN    Resistive Pull Down 
*  TestTimer_DM_RES_UPDWN  Resistive Pull Up/Down 
*  TestTimer_DM_DIG_HIZ    High Impedance Digital 
*  TestTimer_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void TestTimer_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(TestTimer__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: TestTimer_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro TestTimer_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 TestTimer_Read(void) 
{
    return (uint8)((TestTimer_PS & TestTimer_MASK) >> TestTimer_SHIFT);
}


/*******************************************************************************
* Function Name: TestTimer_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 TestTimer_ReadDataReg(void) 
{
    return (uint8)((TestTimer_DR & TestTimer_MASK) >> TestTimer_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(TestTimer_INTSTAT) 

    /*******************************************************************************
    * Function Name: TestTimer_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 TestTimer_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(TestTimer_INTSTAT & TestTimer_MASK);
		TestTimer_INTSTAT = maskedStatus;
        return maskedStatus >> TestTimer_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
