/*******************************************************************************
* File Name: UART_SCB_SPI_UART_PVT.h
* Version 2.0
*
* Description:
*  This private file provides constants and parameter values for the
*  SCB Component in SPI and UART modes.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_PVT_UART_SCB_H)
#define CY_SCB_SPI_UART_PVT_UART_SCB_H

#include "UART_SCB_SPI_UART.h"


/***************************************
*     Internal Global Vars
***************************************/

#if(UART_SCB_INTERNAL_RX_SW_BUFFER_CONST)
    extern volatile uint32  UART_SCB_rxBufferHead;
    extern volatile uint32  UART_SCB_rxBufferTail;
    extern volatile uint8   UART_SCB_rxBufferOverflow;
#endif /* (UART_SCB_INTERNAL_RX_SW_BUFFER_CONST) */

#if(UART_SCB_INTERNAL_TX_SW_BUFFER_CONST)
    extern volatile uint32  UART_SCB_txBufferHead;
    extern volatile uint32  UART_SCB_txBufferTail;
#endif /* (UART_SCB_INTERNAL_TX_SW_BUFFER_CONST) */

#if(UART_SCB_INTERNAL_RX_SW_BUFFER)
    extern volatile uint8 UART_SCB_rxBufferInternal[UART_SCB_RX_BUFFER_SIZE];
#endif /* (UART_SCB_INTERNAL_RX_SW_BUFFER) */

#if(UART_SCB_INTERNAL_TX_SW_BUFFER)
    extern volatile uint8 UART_SCB_txBufferInternal[UART_SCB_TX_BUFFER_SIZE];
#endif /* (UART_SCB_INTERNAL_TX_SW_BUFFER) */


/***************************************
*     Private Function Prototypes
***************************************/

#if(UART_SCB_SCB_MODE_SPI_CONST_CFG)
    void UART_SCB_SpiInit(void);
#endif /* (UART_SCB_SCB_MODE_SPI_CONST_CFG) */

#if(UART_SCB_SPI_WAKE_ENABLE_CONST)
    void UART_SCB_SpiSaveConfig(void);
    void UART_SCB_SpiRestoreConfig(void);
#endif /* (UART_SCB_SPI_WAKE_ENABLE_CONST) */

#if(UART_SCB_SCB_MODE_UART_CONST_CFG)
    void UART_SCB_UartInit(void);
#endif /* (UART_SCB_SCB_MODE_UART_CONST_CFG) */

#if(UART_SCB_UART_WAKE_ENABLE_CONST)
    void UART_SCB_UartSaveConfig(void);
    void UART_SCB_UartRestoreConfig(void);
    #define UART_SCB_UartStop() \
        do{                             \
            UART_SCB_UART_RX_CTRL_REG &= ~UART_SCB_UART_RX_CTRL_SKIP_START; \
        }while(0)
#else
        #define UART_SCB_UartStop() do{ /* Does nothing */ }while(0)

#endif /* (UART_SCB_UART_WAKE_ENABLE_CONST) */

/* Interrupt processing */
#define UART_SCB_SpiUartEnableIntRx(intSourceMask)  UART_SCB_SetRxInterruptMode(intSourceMask)
#define UART_SCB_SpiUartEnableIntTx(intSourceMask)  UART_SCB_SetTxInterruptMode(intSourceMask)
uint32  UART_SCB_SpiUartDisableIntRx(void);
uint32  UART_SCB_SpiUartDisableIntTx(void);


/***************************************
*         UART API Constants
***************************************/

/* UART RX and TX position to be used in UART_SCB_SetPins() */
#define UART_SCB_UART_RX_PIN_ENABLE    (UART_SCB_UART_RX)
#define UART_SCB_UART_TX_PIN_ENABLE    (UART_SCB_UART_TX)

/* UART RTS and CTS position to be used in  UART_SCB_SetPins() */
#define UART_SCB_UART_RTS_PIN_ENABLE    (0x10u)
#define UART_SCB_UART_CTS_PIN_ENABLE    (0x20u)

#endif /* (CY_SCB_SPI_UART_PVT_UART_SCB_H) */


/* [] END OF FILE */
