/**
 * @file main.c
 * @author  Reiner Wehner 
 * @date    10.11.2015 - first implement
 *
 * @section LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details at
 * https://www.gnu.org/copyleft/gpl.html
 *
 * @section rotary encoder in PSoC 
 *          ir method with debouncing
 *          decode based on the method of Peter Danegger
 *          https://www.mikrocontroller.net/articles/Drehgeber#Flankenerkennung_von_A_und_Pegelauswertung_von_B
 * *           
 * @todo
 *
 * @version 1.0
 */
#include <project.h>
#include <stdio.h>
#include "encoder_sw_ir.h"

//**************************************************************************//
//* defines                                                                *//
//**************************************************************************//
#define UART_MAX_STR_LEN 40                  /* max stringlenght = 40 chars*/

#define WELCOME1 "RW Rotary SW IR Deb"
#define WELCOME2 "101115"

//**************************************************************************//
//* prototypes                                                             *//
//**************************************************************************//
void lcd_update();             //print encoder data to lcd


//**************************************************************************//
//* globals, typedefs                                                      *//
//**************************************************************************//

int main(){
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */    
    //Starts the Components 
    LCD_Char_Start();
    encoder_init(); 
    
    /*Welcome, version, date*/
    LCD_Char_PrintString(WELCOME1);
    LCD_Char_Position(1u, 0);   
    LCD_Char_PrintString(WELCOME2);
    CyDelay(3000u);
    LCD_Char_ClearDisplay();   
  
    CyGlobalIntEnable; /* Uncomment this line to enable global interrupts. */
        
    while(1){
        //encoder_update();  
        lcd_update();

        if (myEncoder.switchPressed){  //set encoder mode 0,1,2
            myEncoder.encoderMode++;
            if (3 == myEncoder.encoderMode) { //only 3 different modes
               myEncoder.encoderMode = 0;
            }  
            //set encoder to initial values
            myEncoder.counterValue = INITIAL_COUNTER;
            myEncoder.sLast = 0;
            
            myEncoder.switchPressed = 0;
        }
        
    }
}

//**************************************************************************//
//* function lcd_update                                                    *//
//* Description: print encoder data to lcd                                 *//
//**************************************************************************//
void lcd_update() {
    char lcdRow[21];    
    LCD_Char_Position(0u, 0u);   
    sprintf(lcdRow, "enc:%5u em:%1u dir:%c",
                    myEncoder.counterValue,
                    (1 << myEncoder.encoderMode),
                    myEncoder.direction) ;
    LCD_Char_PrintString(lcdRow);
    LCD_Char_Position(1u, 0u);   
    sprintf(lcdRow, "counts:%-10i",
                    (int) (myEncoder.counterValue - INITIAL_COUNTER));
    LCD_Char_PrintString(lcdRow);
} 

/* [] END OF FILE */
